<?php
/**
 * The header for our theme.
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package StarterBlog
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="viewport" content="width=device-width, initial-scale=1">
<link rel="profile" href="http://gmpg.org/xfn/11">
<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'starter-blog' ); ?></a>

	<header id="masthead" class="site-header" role="banner">
		<div class="container">
			<div class="row">
				<div class="col-sm social">
					<ul class="social-header clearfix">
						<?php if( get_theme_mod( 'social_facebook' )): ?>
							<li><a href="<?php echo esc_url( get_theme_mod( 'social_facebook' ) ); ?>" class="facebook"><i class="fa fa-facebook"></i></a></li>
						<?php endif; ?>
						<?php if( get_theme_mod( 'social_twitter' )): ?>
							<li><a href="<?php echo esc_url( get_theme_mod( 'social_twitter' ) ); ?>" class="twitter"><i class="fa fa-twitter"></i></a></li>
						<?php endif; ?>
						<?php if( get_theme_mod( 'social_instagram' )): ?>
							<li><a href="<?php echo esc_url( get_theme_mod( 'social_instagram' ) ); ?>" class="instagram"><i class="fa fa-instagram"></i></a></li>
						<?php endif; ?>
						<?php if( get_theme_mod( 'social_youtube' )): ?>
							<li><a href="<?php echo esc_url( get_theme_mod( 'social_youtube' ) ); ?>" class="youtube"><i class="fa fa-youtube"></i></a></li>
						<?php endif; ?>
					</ul>
				</div>
				<div class="col-sm brand">
					<div class="site-branding text-center">
						<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
						<p class="site-description"><?php bloginfo( 'description' ); ?></p>
						<?php
						if ( function_exists( 'the_custom_logo' ) ) {
							the_custom_logo();
						}
						?>
					</div><!-- .site-branding -->
				</div>
				<div class="col-sm menu-col">
					<nav id="site-navigation" class="main-navigation" role="navigation">
						<button class="menu-toggle" aria-controls="header-menu" aria-expanded="false">
							<span class="sr-only"><?php esc_html_e( 'Menu', 'starter-blog' ); ?></span>
							<span class="icon-bar"></span>
							<span class="icon-bar"></span>
							<span class="icon-bar"></span>
						</button>
						<?php wp_nav_menu( array( 'theme_location' => 'headermenu', 'menu_id' => 'header-menu', 'container_class' => 'header-menu' ) ); ?>
					</nav><!-- #site-navigation -->
				</div>
			</div>
		</div>
	</header><!-- #masthead -->

	<div id="main_navbar" class="navbar navbar-expand-md navbar-light bg-light">
			<!-- you can remove this container wrapper if you want things full width -->
			<div class="menu container">
					<button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#headerNav" aria-controls="headerNav" aria-expanded="false" aria-label="<?php esc_attr_e( 'Toggle navigation', 'starter-blog' ); ?>">
							<span class="navbar-toggler-icon"></span><span class="sr-only"><?php esc_html_e( 'Toggle Navigation', 'starter-blog' ); ?></span>
					</button>
					<nav class="collapse navbar-collapse" id="headerNav" role="navigation" aria-label="Main Menu">
							<span class="sr-only"><?php esc_html_e( 'Main Menu', 'starter-blog' ); ?></span>
							<?php
							wp_nav_menu( array(
									'theme_location' => 'primary',
									'depth' => 5,
									'container' => false,
									'menu_class' => 'navbar-nav mr-auto',
									'fallback_cb' => 'WP_Bootstrap_Navwalker::fallback',
									'walker' => new WP_Bootstrap_Navwalker(),
							) );
					?>
					</nav>
			</div>
	</div>
